@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine.h.in,v 1.136.2.3 2005/04/25 14:43:13 mroi Exp $
+ * $Id: xine.h.in,v 1.136.2.4 2005/07/17 21:49:33 miguelfreitas Exp $
  *
  * public xine-lib (libxine) interface and documentation
  *
@@ -113,8 +113,8 @@ int  xine_check_version (int major, int minor, int sub) ;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 0
-#define XINE_SUB_VERSION   1
-#define XINE_VERSION       "1.0.1"
+#define XINE_SUB_VERSION   3
+#define XINE_VERSION       "1.0.3"
 
 /*
  * pre-init the xine engine
@@ -895,6 +895,32 @@ const char *xine_get_meta_info   (xine_stream_t *stream, int info);
 #define XINE_STREAM_INFO_AUDIO_MODE        26
 #define XINE_STREAM_INFO_SKIPPED_FRAMES    27 /* for 1000 frames delivered */
 #define XINE_STREAM_INFO_DISCARDED_FRAMES  28 /* for 1000 frames delivered */
+#define XINE_STREAM_INFO_VIDEO_AFD         29
+#define XINE_STREAM_INFO_DVD_TITLE_NUMBER   30
+#define XINE_STREAM_INFO_DVD_TITLE_COUNT    31
+#define XINE_STREAM_INFO_DVD_CHAPTER_NUMBER 32
+#define XINE_STREAM_INFO_DVD_CHAPTER_COUNT  33
+#define XINE_STREAM_INFO_DVD_ANGLE_NUMBER   34
+#define XINE_STREAM_INFO_DVD_ANGLE_COUNT    35
+
+/* possible values for XINE_STREAM_INFO_VIDEO_AFD */
+#define XINE_VIDEO_AFD_NOT_PRESENT         -1
+#define XINE_VIDEO_AFD_RESERVED_0          0
+#define XINE_VIDEO_AFD_RESERVED_1          1
+#define XINE_VIDEO_AFD_BOX_16_9_TOP        2
+#define XINE_VIDEO_AFD_BOX_14_9_TOP        3
+#define XINE_VIDEO_AFD_BOX_GT_16_9_CENTRE  4
+#define XINE_VIDEO_AFD_RESERVED_5          5
+#define XINE_VIDEO_AFD_RESERVED_6          6
+#define XINE_VIDEO_AFD_RESERVED_7          7
+#define XINE_VIDEO_AFD_SAME_AS_FRAME       8
+#define XINE_VIDEO_AFD_4_3_CENTRE          9
+#define XINE_VIDEO_AFD_16_9_CENTRE         10
+#define XINE_VIDEO_AFD_14_9_CENTRE         11
+#define XINE_VIDEO_AFD_RESERVED_12         12
+#define XINE_VIDEO_AFD_4_3_PROTECT_14_9    13
+#define XINE_VIDEO_AFD_16_9_PROTECT_14_9   14
+#define XINE_VIDEO_AFD_16_9_PROTECT_4_3    15
 
 /* xine_get_meta_info */
 #define XINE_META_INFO_TITLE               0
@@ -1751,6 +1777,7 @@ typedef struct {
 #define XINE_MSG_SECURITY		10 /* (security message) */
 #define XINE_MSG_AUDIO_OUT_UNAVAILABLE	11 /* none               */
 #define XINE_MSG_PERMISSION_ERROR       12 /* (file name or mrl) */
+#define XINE_MSG_FILE_EMPTY             13 /* file is empty      */
 
 /* opaque xine_event_queue_t */
 typedef struct xine_event_queue_s xine_event_queue_t;
