@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: audio_directx2_out.c,v 1.2.2.1 2005/02/09 19:39:04 mroi Exp $
+ * $Id: audio_directx2_out.c,v 1.2.2.2 2005/07/17 21:49:40 miguelfreitas Exp $
  *
  *
  * xine audio output plugin using DirectX
@@ -129,7 +129,7 @@ typedef struct {
   int paused;                      /* paused mode */
   int finished;                    /* driver finished */
   int failed;                      /* don't open modal dialog again */
-  int count;                       /* number of current free parts */
+  int count;                       /* current free part number */
 
   pthread_t buffer_service;        /* service thread for operating with DSB */
   pthread_cond_t data_cond;        /* signals on data */
@@ -176,7 +176,7 @@ static char *dsound_strerror(HRESULT err) {
     case DSERR_BUFFERLOST: return _("memory buffer has been lost and must be restored");
     case DSERR_CONTROLUNAVAIL: return _("requested buffer control is not available");
     case DSERR_GENERIC: return _("undetermined error inside DirectSound subsystem");
-#ifdef HWUNAVAIL
+#ifdef DSERR_HWUNAVAIL
     case DSERR_HWUNAVAIL: return _("DirectSound hardware device is unavailable");
 #endif
     case DSERR_INVALIDCALL: return _("function is not valid for the current state of the object");
