@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -20,7 +20,7 @@
  * Compact Disc Digital Audio (CDDA) Input Plugin 
  *   by Mike Melanson (melanson@pcisys.net)
  *
- * $Id: input_cdda.c,v 1.69.2.1 2005/04/20 17:21:07 mroi Exp $
+ * $Id: input_cdda.c,v 1.69.2.2 2005/07/17 21:49:58 miguelfreitas Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,7 +32,12 @@
 #include <unistd.h>
 
 #include <sys/types.h>
+#ifdef SYS_PARAM_H
+#include <sys/param.h>
+#endif
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -684,18 +689,26 @@ static int read_cdrom_frames(cdda_input_plugin_t *this_gen, int frame, int num_f
   unsigned char *data) {
 
   int fd = this_gen->fd;
+#if  __FreeBSD_version < 501106
   struct ioc_read_audio cdda;
+#endif
 
   while( num_frames ) {
+#if  __FreeBSD_version < 501106
     cdda.address_format = CD_MSF_FORMAT;
     cdda.address.msf.minute = frame / CD_SECONDS_PER_MINUTE / CD_FRAMES_PER_SECOND;
     cdda.address.msf.second = (frame / CD_FRAMES_PER_SECOND) % CD_SECONDS_PER_MINUTE;
     cdda.address.msf.frame = frame % CD_FRAMES_PER_SECOND;
     cdda.nframes = 1;
     cdda.buffer = data;
+#endif
 
+#if  __FreeBSD_version >= 501106
+    if (pread(fd, data, CD_RAW_FRAME_SIZE, frame * CD_RAW_FRAME_SIZE) != CD_RAW_FRAME_SIZE) {
+#else
     /* read a frame */
     if(ioctl(fd, CDIOCREADAUDIO, &cdda) < 0) {
+#endif
       perror("CDIOCREADAUDIO");
       return -1;
     }
@@ -1473,7 +1486,7 @@ static void _cdda_save_cached_cddb_infos(cdda_input_plugin_t *this, char *fileco
     return;
   }
   else {
-    fprintf(fd, filecontent);
+    fprintf(fd, "%s", filecontent);
     fclose(fd);
   }
   
@@ -2098,24 +2111,15 @@ static uint32_t cdda_plugin_get_capabilities (input_plugin_t *this_gen) {
 
 static off_t cdda_plugin_read (input_plugin_t *this_gen, char *buf, off_t len) {
 
-  /* only allow reading in block-sized chunks */
-
-  return 0;
-}
-
-static buf_element_t *cdda_plugin_read_block (input_plugin_t *this_gen, fifo_buffer_t *fifo, 
-  off_t nlen) {
-
   cdda_input_plugin_t *this = (cdda_input_plugin_t *) this_gen;
-  buf_element_t *buf;
-  unsigned char frame_data[CD_RAW_FRAME_SIZE];
   int err = 0;
 
-  if (nlen != CD_RAW_FRAME_SIZE)
-    return NULL;
+  /* only allow reading in block-sized chunks */
+  if (len != CD_RAW_FRAME_SIZE)
+    return 0;
 
   if (this->current_frame > this->last_frame)
-    return NULL;
+    return 0;
 
   /* populate frame cache */
   if( this->cache_first == -1 ||
@@ -2143,16 +2147,28 @@ static buf_element_t *cdda_plugin_read_block (input_plugin_t *this_gen, fifo_buf
   }
 
   if( err < 0 )
-    return NULL;
+    return 0;
     
-  memcpy(frame_data, this->cache[this->current_frame-this->cache_first], CD_RAW_FRAME_SIZE);
+  memcpy(buf, this->cache[this->current_frame-this->cache_first], CD_RAW_FRAME_SIZE);
   this->current_frame++;
 
+  return CD_RAW_FRAME_SIZE;
+}
+
+static buf_element_t *cdda_plugin_read_block (input_plugin_t *this_gen, fifo_buffer_t *fifo, 
+  off_t nlen) {
+
+  buf_element_t *buf;
+
   buf = fifo->buffer_pool_alloc(fifo);
   buf->content = buf->mem;
   buf->type = BUF_DEMUX_BLOCK;
-  buf->size = CD_RAW_FRAME_SIZE;
-  memcpy(buf->mem, frame_data, CD_RAW_FRAME_SIZE);
+
+  buf->size = cdda_plugin_read(this_gen, buf->content, nlen);
+  if (buf->size == 0) {
+    buf->free_buffer(buf);
+    buf = NULL;
+  }
 
   return buf;
 }
