@@ -492,8 +492,8 @@ static void interp_header (mmsh_t *this) {
 
         this->packet_length = LE_32(this->asf_header + i + 92 - 24);
         this->file_length   = LE_64(this->asf_header + i + 40 - 24);
-        lprintf ("file object, file_length = %lld, packet length = %d",
-		 this->file_length, this->packet_count);
+        /*lprintf ("file object, file_length = %lld, packet length = %d",
+		 this->file_length, this->packet_count);*/
         break;
 
       case GUID_ASF_STREAM_PROPERTIES:
