@@ -44,12 +44,6 @@
 #include <errno.h>
 #include <math.h>
 
-#if defined (__SVR4) && defined (__sun)
-# include <sys/int_types.h>
-#else
-# include <stdint.h>
-#endif
-
 #include <sys/types.h>
 #if defined(__FreeBSD__)
 #include <machine/param.h>
