@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: audio_decoder.c,v 1.133 2004/12/16 13:59:06 mroi Exp $
+ * $Id: audio_decoder.c,v 1.133.2.1 2005/04/20 17:21:14 mroi Exp $
  *
  *
  * functions that implement audio decoding
@@ -148,7 +148,7 @@ static void *audio_decoder_loop (void *stream_gen) {
 
       pthread_cond_broadcast (&stream->counter_changed);
 
-      if (stream->video_thread) {
+      if (stream->video_thread_created) {
         while (stream->finished_count_video < stream->finished_count_audio) {
           struct timeval tv;
           struct timespec ts;
@@ -255,7 +255,8 @@ static void *audio_decoder_loop (void *stream_gen) {
         
         if ( (i==stream->audio_track_map_entries) 
 	     || (stream->audio_track_map[i] != buf->type) ) {
-          
+          xine_event_t  ui_event;
+
           j = stream->audio_track_map_entries;
 
           if (j >= 50)
@@ -267,6 +268,10 @@ static void *audio_decoder_loop (void *stream_gen) {
           }
           stream->audio_track_map[i] = buf->type;
           stream->audio_track_map_entries++;
+
+	  ui_event.type        = XINE_EVENT_UI_CHANNELS_CHANGED;
+	  ui_event.data_length = 0;
+	  xine_event_send (stream, &ui_event);
         }
 
 	/* find out which audio type to decode */
@@ -485,7 +490,8 @@ void _x_audio_decoder_init (xine_stream_t *stream) {
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
     pthread_attr_setscope(&pth_attrs, PTHREAD_SCOPE_SYSTEM);
-  
+ 
+    stream->audio_thread_created = 1; 
     if ((err = pthread_create (&stream->audio_thread,
                                &pth_attrs, audio_decoder_loop, stream)) != 0) {
       xprintf (stream->xine, XINE_VERBOSITY_DEBUG, 
@@ -502,14 +508,15 @@ void _x_audio_decoder_shutdown (xine_stream_t *stream) {
   buf_element_t *buf;
   void          *p;
 
-  if (stream->audio_thread) {
+  if (stream->audio_thread_created) {
     /* stream->audio_fifo->clear(stream->audio_fifo); */
 
     buf = stream->audio_fifo->buffer_pool_alloc (stream->audio_fifo);
     buf->type = BUF_CONTROL_QUIT;
     stream->audio_fifo->put (stream->audio_fifo, buf);
     
-    pthread_join (stream->audio_thread, &p); 
+    pthread_join (stream->audio_thread, &p);
+    stream->audio_thread_created = 0;
   }
     
   stream->audio_fifo->dispose (stream->audio_fifo);
