@@ -964,7 +964,7 @@ void xine_config_save (xine_t *xine, const char *filename) {
     f_backup = fopen(temp, "w");
     f_config = fopen(filename, "r");
     
-    if (f_config && f_backup && (stat(filename, &config_stat) == 0) && (config_stat.st_size > 0)) {
+    if (f_config && f_backup && (stat(filename, &config_stat) == 0)) {
       char    *buf = NULL;
       size_t   rlen;
       
