@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: load_plugins.c,v 1.193.2.2 2005/04/20 17:21:16 mroi Exp $
+ * $Id: load_plugins.c,v 1.193.2.5 2005/07/18 01:46:40 miguelfreitas Exp $
  *
  *
  * Load input/demux/audio_out/video_out/codec plugins
@@ -32,7 +32,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <dlfcn.h>
 #include <string.h>
 #include <errno.h>
@@ -42,6 +44,7 @@
 
 #define LOG_MODULE "load_plugins"
 #define LOG_VERBOSE
+
 /*
 #define LOG
 */
@@ -60,9 +63,10 @@
 #include "xineutils.h"
 #include "compat.h"
 
+#if 0
+
 static char *plugin_name;
 
-#if 0
 #if DONT_CATCH_SIGSEGV
 
 #define install_segv_handler()
@@ -523,30 +527,31 @@ static void collect_plugins(xine_t *this, char *path){
   dir = opendir(path);
   if (dir) {
     struct dirent *pEntry;
-    int path_len;
+    size_t path_len, str_size;
     char *str = NULL;
 
     path_len = strlen(path);
-    str = malloc(path_len * 2 + 2); /* +2 for '/' and '\0' */
+    str_size = path_len * 2 + 2; /* +2 for '/' and '\0' */
+    str = malloc(str_size);
     xine_fast_memcpy(str, path, path_len);
     str[path_len] = '/';
     str[path_len + 1] = '\0';
 
     while ((pEntry = readdir (dir)) != NULL) {
-      size_t str_size = 0;
-      size_t new_str_size = 0;
+      size_t new_str_size, d_len;
       void *lib = NULL;
       plugin_info_t *info = NULL;
       
       struct stat statbuffer;
 
-      new_str_size = path_len + pEntry->d_reclen + 2;
+      d_len = strlen(pEntry->d_name);
+      new_str_size = path_len + d_len + 2;
       if (str_size < new_str_size) {
 	str_size = new_str_size + new_str_size / 2;
 	str = realloc(str, str_size);
       }
 
-      xine_fast_memcpy(&str[path_len + 1], pEntry->d_name, pEntry->d_reclen + 1);
+      xine_fast_memcpy(&str[path_len + 1], pEntry->d_name, d_len + 1);
 
       if (stat(str, &statbuffer)) {
 	xine_log (this, XINE_LOG_PLUGIN, _("load_plugins: unable to stat %s\n"), str);
@@ -725,7 +730,8 @@ static void _dispose_plugin_class(plugin_node_t *node) {
       break;
     }
     node->plugin_class = NULL;
-    dec_file_ref(node->file);
+    if (node->file)
+      dec_file_ref(node->file);
   }
 }
 
@@ -1082,21 +1088,21 @@ void _x_scan_plugins (xine_t *this) {
   if ((pluginpath = getenv("XINE_PLUGIN_PATH")) != NULL) {
     pluginpath = strdup(pluginpath);
   } else {
-    char *str1, *str2;
+    const char *str1, *str2;
     int len;
 
     str1 = "~/.xine/plugins";
     str2 = XINE_PLUGINDIR;
     len = strlen(str1) + strlen(str2) + 2;
     pluginpath = xine_xmalloc(len);
-    snprintf(pluginpath, len, "%s:%s", str1, str2);
+    snprintf(pluginpath, len, "%s" XINE_DIRECTORY_SEPARATOR_STRING "%s", str1, str2);
   }
   plugindir = xine_xmalloc(strlen(pluginpath)+strlen(homedir)+2);
   j=0;
   lenpluginpath = strlen(pluginpath);
   for (i=0; i <= lenpluginpath; ++i){
     switch (pluginpath[i]){
-    case ':':
+    case XINE_DIRECTORY_SEPARATOR_CHAR:
     case '\0':
       plugindir[j] = '\0';
       collect_plugins(this, plugindir);
@@ -1132,28 +1138,27 @@ input_plugin_t *_x_find_input_plugin (xine_stream_t *stream, const char *mrl) {
   xine_t           *xine = stream->xine;
   plugin_catalog_t *catalog = xine->plugin_catalog;
   plugin_node_t    *node;
+  input_plugin_t   *plugin = NULL;
 
   pthread_mutex_lock (&catalog->lock);
 
   node = xine_list_first_content (catalog->plugin_lists[PLUGIN_INPUT - 1]);
   while (node) {
-    input_plugin_t   *plugin;
 
-    if (!node->plugin_class && !_load_plugin_class(xine, node, NULL))
-      return NULL;
-    if ((plugin = ((input_class_t *)node->plugin_class)->get_instance(node->plugin_class, stream, mrl))) {
-      inc_node_ref(node);
-      plugin->node = node;
-      pthread_mutex_unlock (&catalog->lock);
-      return plugin;
+    if (node->plugin_class || _load_plugin_class(xine, node, NULL)) {
+      if ((plugin = ((input_class_t *)node->plugin_class)->get_instance(node->plugin_class, stream, mrl))) {
+        inc_node_ref(node);
+        plugin->node = node;
+        break;
+      }
     }
-
+    
     node = xine_list_next_content (stream->xine->plugin_catalog->plugin_lists[PLUGIN_INPUT - 1]);
   }
 
   pthread_mutex_unlock (&catalog->lock);
 
-  return NULL;
+  return plugin;
 }
 
 
@@ -1176,6 +1181,7 @@ static demux_plugin_t *probe_demux (xine_stream_t *stream, int method1, int meth
   int               i;
   int               methods[3];
   plugin_catalog_t *catalog = stream->xine->plugin_catalog;
+  demux_plugin_t   *plugin = NULL;
 
   methods[0] = method1;
   methods[1] = method2;
@@ -1187,7 +1193,7 @@ static demux_plugin_t *probe_demux (xine_stream_t *stream, int method1, int meth
   }
 
   i = 0;
-  while (methods[i] != -1) {
+  while (methods[i] != -1 && !plugin) {
 
     plugin_node_t *node;
 
@@ -1198,18 +1204,15 @@ static demux_plugin_t *probe_demux (xine_stream_t *stream, int method1, int meth
     node = xine_list_first_content (catalog->plugin_lists[PLUGIN_DEMUX - 1]);
 
     while (node) {
-      demux_plugin_t *plugin;
 
       xprintf(stream->xine, XINE_VERBOSITY_DEBUG, "load_plugins: probing demux '%s'\n", node->info->id);
 
-      if (!node->plugin_class && !_load_plugin_class(stream->xine, node, NULL))
-	return NULL;
-
-      if ((plugin = ((demux_class_t *)node->plugin_class)->open_plugin(node->plugin_class, stream, input))) {
-	inc_node_ref(node);
-	plugin->node = node;
-	pthread_mutex_unlock (&catalog->lock);
-	return plugin;
+      if (node->plugin_class || _load_plugin_class(stream->xine, node, NULL)) {
+        if ((plugin = ((demux_class_t *)node->plugin_class)->open_plugin(node->plugin_class, stream, input))) {
+	  inc_node_ref(node);
+	  plugin->node = node;
+	  break;
+        }
       }
 
       node = xine_list_next_content (stream->xine->plugin_catalog->plugin_lists[PLUGIN_DEMUX - 1]);
@@ -1220,7 +1223,7 @@ static demux_plugin_t *probe_demux (xine_stream_t *stream, int method1, int meth
     i++;
   }
 
-  return NULL;
+  return plugin;
 }
 
 demux_plugin_t *_x_find_demux_plugin (xine_stream_t *stream, input_plugin_t *input) {
@@ -1252,7 +1255,7 @@ demux_plugin_t *_x_find_demux_plugin_by_name(xine_stream_t *stream, const char *
 
   plugin_catalog_t  *catalog = stream->xine->plugin_catalog;
   plugin_node_t     *node;
-  demux_plugin_t    *plugin;
+  demux_plugin_t    *plugin = NULL;
 
   pthread_mutex_lock(&catalog->lock);
   node = xine_list_first_content(catalog->plugin_lists[PLUGIN_DEMUX - 1]);
@@ -1260,21 +1263,19 @@ demux_plugin_t *_x_find_demux_plugin_by_name(xine_stream_t *stream, const char *
 
   while (node) {
     if (strcasecmp(node->info->id, name) == 0) {
-      if (!node->plugin_class && !_load_plugin_class(stream->xine, node, NULL))
-	return NULL;
-
-      if ((plugin = ((demux_class_t *)node->plugin_class)->open_plugin(node->plugin_class, stream, input))) {
-	inc_node_ref(node);
-	plugin->node = node;
-	pthread_mutex_unlock (&catalog->lock);
-	return plugin;
+      if (node->plugin_class || _load_plugin_class(stream->xine, node, NULL)) {
+        if ((plugin = ((demux_class_t *)node->plugin_class)->open_plugin(node->plugin_class, stream, input))) {
+	  inc_node_ref(node);
+	  plugin->node = node;
+	  break;
+        }
       }
     }
     node = xine_list_next_content(catalog->plugin_lists[PLUGIN_DEMUX - 1]);
   }
 
   pthread_mutex_unlock(&catalog->lock);
-  return NULL;
+  return plugin;
 }
 
 /*
@@ -1293,14 +1294,14 @@ demux_plugin_t *_x_find_demux_plugin_last_probe(xine_stream_t *stream, const cha
   xine_t           *xine = stream->xine;
   plugin_catalog_t *catalog = xine->plugin_catalog;
   plugin_node_t    *last_demux = NULL;
-  demux_plugin_t   *plugin;
+  demux_plugin_t   *plugin = NULL;
 
   methods[0] = METHOD_BY_CONTENT;
   methods[1] = METHOD_BY_EXTENSION;
   methods[2] = -1;
 
   i = 0;
-  while (methods[i] != -1) {
+  while (methods[i] != -1 && !plugin) {
 
     plugin_node_t *node;
 
@@ -1319,16 +1320,14 @@ demux_plugin_t *_x_find_demux_plugin_last_probe(xine_stream_t *stream, const cha
       } else {
 	xprintf(stream->xine, XINE_VERBOSITY_DEBUG, 
 		"load_plugin: probing '%s' (method %d)...\n", node->info->id, stream->content_detection_method );
-	if (!node->plugin_class && !_load_plugin_class(xine, node, NULL))
-	  return NULL;
-
-        if ((plugin = ((demux_class_t *)node->plugin_class)->open_plugin(node->plugin_class, stream, input))) {
-	  xprintf (stream->xine, XINE_VERBOSITY_DEBUG,
-		   "load_plugins: using demuxer '%s' (instead of '%s')\n", node->info->id, last_demux_name);
-	  inc_node_ref(node);
-	  plugin->node = node;
-	  pthread_mutex_unlock (&catalog->lock);
-	  return plugin;
+	if (node->plugin_class || _load_plugin_class(xine, node, NULL)) {
+          if ((plugin = ((demux_class_t *)node->plugin_class)->open_plugin(node->plugin_class, stream, input))) {
+	    xprintf (stream->xine, XINE_VERBOSITY_DEBUG,
+		     "load_plugins: using demuxer '%s' (instead of '%s')\n", node->info->id, last_demux_name);
+	    inc_node_ref(node);
+	    plugin->node = node;
+	    break;
+          }
         }
       }
 
@@ -1340,6 +1339,9 @@ demux_plugin_t *_x_find_demux_plugin_last_probe(xine_stream_t *stream, const cha
     i++;
   }
 
+  if( plugin )
+    return plugin;
+
   if( !last_demux )
     return NULL;
 
@@ -1747,6 +1749,7 @@ video_decoder_t *_x_get_video_decoder (xine_stream_t *stream, uint8_t stream_typ
   plugin_node_t    *node;
   int               i, j;
   plugin_catalog_t *catalog = stream->xine->plugin_catalog;
+  video_decoder_t  *vd = NULL;
 
   lprintf ("looking for video decoder for streamtype %02x\n", stream_type);
 
@@ -1754,13 +1757,10 @@ video_decoder_t *_x_get_video_decoder (xine_stream_t *stream, uint8_t stream_typ
 
   for (i = 0; i < PLUGINS_PER_TYPE; i++) {
 
-    video_decoder_t *vd=NULL;
-
     node = catalog->video_decoder_map[stream_type][i];
 
     if (!node) {
-      pthread_mutex_unlock (&catalog->lock);
-      return NULL;
+      break;
     }
 
     if (!node->plugin_class && !_load_plugin_class (stream->xine, node, NULL)) {
@@ -1784,8 +1784,7 @@ video_decoder_t *_x_get_video_decoder (xine_stream_t *stream, uint8_t stream_typ
           "load_plugins: plugin %s will be used for video streamtype %02x.\n", 
           node->info->id, stream_type);
       
-      pthread_mutex_unlock (&catalog->lock);
-      return vd;
+      break;
     } else {
       /* remove non working plugin from catalog */
       xprintf(stream->xine, XINE_VERBOSITY_DEBUG,
@@ -1799,7 +1798,7 @@ video_decoder_t *_x_get_video_decoder (xine_stream_t *stream, uint8_t stream_typ
   }
 
   pthread_mutex_unlock (&catalog->lock);
-  return NULL;
+  return vd;
 }
 
 void _x_free_video_decoder (xine_stream_t *stream, video_decoder_t *vd) {
@@ -1821,6 +1820,7 @@ audio_decoder_t *_x_get_audio_decoder (xine_stream_t *stream, uint8_t stream_typ
   plugin_node_t    *node;
   int               i, j;
   plugin_catalog_t *catalog = stream->xine->plugin_catalog;
+  audio_decoder_t  *ad = NULL;
 
   lprintf ("looking for audio decoder for streamtype %02x\n", stream_type);
 
@@ -1828,13 +1828,10 @@ audio_decoder_t *_x_get_audio_decoder (xine_stream_t *stream, uint8_t stream_typ
 
   for (i = 0; i < PLUGINS_PER_TYPE; i++) {
 
-    audio_decoder_t *ad;
-
     node = catalog->audio_decoder_map[stream_type][i];
 
     if (!node) {
-      pthread_mutex_unlock (&catalog->lock);
-      return NULL;
+      break;
     }
 
     if (!node->plugin_class && !_load_plugin_class (stream->xine, node, NULL)) {
@@ -1857,8 +1854,7 @@ audio_decoder_t *_x_get_audio_decoder (xine_stream_t *stream, uint8_t stream_typ
       xprintf(stream->xine, XINE_VERBOSITY_DEBUG,
           "load_plugins: plugin %s will be used for audio streamtype %02x.\n", 
           node->info->id, stream_type);
-      pthread_mutex_unlock (&catalog->lock);
-      return ad;
+      break;
     } else {
       /* remove non working plugin from catalog */
       xprintf(stream->xine, XINE_VERBOSITY_DEBUG,
@@ -1872,7 +1868,7 @@ audio_decoder_t *_x_get_audio_decoder (xine_stream_t *stream, uint8_t stream_typ
   }
 
   pthread_mutex_unlock (&catalog->lock);
-  return NULL;
+  return ad;
 }
 
 void _x_free_audio_decoder (xine_stream_t *stream, audio_decoder_t *ad) {
@@ -1942,7 +1938,7 @@ void xine_plugins_garbage_collector(xine_t *self) {
     _unload_unref_plugins(self, self->plugin_catalog->plugin_lists[i]);
   } 
 
-#ifdef LOG
+#if 0
   {
     plugin_file_t *file;
 
@@ -1970,19 +1966,18 @@ spu_decoder_t *_x_get_spu_decoder (xine_stream_t *stream, uint8_t stream_type) {
   plugin_node_t    *node;
   int               i, j;
   plugin_catalog_t *catalog = stream->xine->plugin_catalog;
+  spu_decoder_t    *sd = NULL;
 
   lprintf ("looking for spu decoder for streamtype %02x\n", stream_type);
 
   pthread_mutex_lock (&catalog->lock);
 
   for (i = 0; i < PLUGINS_PER_TYPE; i++) {
-    spu_decoder_t *sd;
 
     node = catalog->spu_decoder_map[stream_type][i];
 
     if (!node) {
-      pthread_mutex_unlock (&catalog->lock);
-      return NULL;
+      break;
     }
 
     if (!node->plugin_class && !_load_plugin_class (stream->xine, node, NULL)) {
@@ -2005,8 +2000,7 @@ spu_decoder_t *_x_get_spu_decoder (xine_stream_t *stream, uint8_t stream_type) {
       xprintf(stream->xine, XINE_VERBOSITY_DEBUG,
           "load_plugins: plugin %s will be used for spu streamtype %02x.\n", 
           node->info->id, stream_type);
-      pthread_mutex_unlock (&catalog->lock);
-      return sd;
+      break;
     } else {
       /* remove non working plugin from catalog */
       xprintf(stream->xine, XINE_VERBOSITY_DEBUG,
@@ -2020,7 +2014,7 @@ spu_decoder_t *_x_get_spu_decoder (xine_stream_t *stream, uint8_t stream_type) {
   }
 
   pthread_mutex_unlock (&catalog->lock);
-  return NULL;
+  return sd;
 }
 
 void _x_free_spu_decoder (xine_stream_t *stream, spu_decoder_t *sd) {
@@ -2150,6 +2144,7 @@ xine_post_t *xine_post_init(xine_t *xine, const char *name, int inputs,
 			    xine_video_port_t **video_target) {
   plugin_catalog_t *catalog = xine->plugin_catalog;
   plugin_node_t    *node;
+  post_plugin_t    *post = NULL;
   
   if( !name )
     return NULL;
@@ -2160,13 +2155,11 @@ xine_post_t *xine_post_init(xine_t *xine, const char *name, int inputs,
   while (node) {
     
     if (strcmp(node->info->id, name) == 0) {
-      post_plugin_t *post;
       
       if (!node->plugin_class && !_load_plugin_class(xine, node, NULL)) {
         xprintf(xine, XINE_VERBOSITY_DEBUG,
 		"load_plugins: requested post plugin %s failed to load\n", name);
-	pthread_mutex_unlock(&catalog->lock);
-	return NULL;
+	break;
       }
       
       post = ((post_class_t *)node->plugin_class)->open_plugin(node->plugin_class,
@@ -2181,7 +2174,6 @@ xine_post_t *xine_post_init(xine_t *xine, const char *name, int inputs,
 	post->xine = xine;
 	post->node = node;
 	inc_node_ref(node);
-	pthread_mutex_unlock(&catalog->lock);
 	
 	/* init the lists of announced connections */
 	i = 0;
@@ -2217,12 +2209,11 @@ xine_post_t *xine_post_init(xine_t *xine, const char *name, int inputs,
 	/* copy the post plugin type to the public part */
 	post->xine_post.type = ((post_info_t *)node->info->special_info)->type;
 	
-	return &post->xine_post;
+	break;
       } else {
         xprintf(xine, XINE_VERBOSITY_DEBUG,
 		"load_plugins: post plugin %s failed to instantiate itself\n", name);
-	pthread_mutex_unlock(&catalog->lock);
-	return NULL;
+	break;
       }
     }
     
@@ -2231,8 +2222,12 @@ xine_post_t *xine_post_init(xine_t *xine, const char *name, int inputs,
   
   pthread_mutex_unlock(&catalog->lock);
   
-  xprintf(xine, XINE_VERBOSITY_DEBUG, "load_plugins: no post plugin named %s found\n", name);
-  return NULL;
+  if(post)
+    return &post->xine_post;
+  else {
+    xprintf(xine, XINE_VERBOSITY_DEBUG, "load_plugins: no post plugin named %s found\n", name);
+    return NULL;
+  }
 }
 
 void xine_post_dispose(xine_t *xine, xine_post_t *post_gen) {
@@ -2500,7 +2495,9 @@ void _x_dispose_plugins (xine_t *this) {
 
     for (i = 0; this->plugin_catalog->prio_desc[i]; i++)
       free(this->plugin_catalog->prio_desc[i]);
-    
+
+    pthread_mutex_destroy(&this->plugin_catalog->lock);
+
     free (this->plugin_catalog);
   }
 }
