@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine.c,v 1.306.2.2 2005/04/20 17:21:17 mroi Exp $
+ * $Id: xine.c,v 1.306.2.4 2005/07/21 02:57:52 miguelfreitas Exp $
  */
 
 /*
@@ -232,6 +232,7 @@ static xine_ticket_t *ticket_init(void) {
   pthread_mutex_init(&port_ticket->lock, NULL);
   pthread_mutex_init(&port_ticket->revoke_lock, NULL);
   pthread_cond_init(&port_ticket->issued, NULL);
+  pthread_cond_init(&port_ticket->revoked, NULL);
   
   return port_ticket;
 }
@@ -288,7 +289,7 @@ static void stop_internal (xine_stream_t *stream) {
   /*
    * stop demux
    */
-  if (stream->demux_plugin && stream->demux_thread) {
+  if (stream->demux_plugin && stream->demux_thread_created) {
     lprintf ("stopping demux\n");
     _x_demux_stop_thread( stream );
     lprintf ("demux stopped\n");
@@ -459,6 +460,7 @@ xine_stream_t *xine_stream_new (xine_t *this,
 
   xine_stream_t *stream;
   int            i;
+  pthread_mutexattr_t attr;
 
   xprintf (this, XINE_VERBOSITY_DEBUG, "xine_stream_new\n");
 
@@ -523,7 +525,6 @@ xine_stream_t *xine_stream_new (xine_t *this,
   pthread_mutex_init (&stream->info_mutex, NULL);
   pthread_mutex_init (&stream->meta_mutex, NULL);
   pthread_mutex_init (&stream->demux_lock, NULL);
-  pthread_mutex_init (&stream->frontend_lock, NULL);
   pthread_mutex_init (&stream->event_queues_lock, NULL);
   pthread_mutex_init (&stream->counter_lock, NULL);
   pthread_cond_init  (&stream->counter_changed, NULL);
@@ -531,6 +532,13 @@ xine_stream_t *xine_stream_new (xine_t *this,
   pthread_cond_init  (&stream->first_frame_reached, NULL);
   pthread_mutex_init (&stream->current_extra_info_lock, NULL);
 
+  /* warning: frontend_lock is a recursive mutex. it must NOT be
+   * used with neither pthread_cond_wait() or pthread_cond_timedwait()
+   */
+  pthread_mutexattr_init(&attr);
+  pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+  pthread_mutex_init (&stream->frontend_lock, &attr);
+
   /*
    * Clear meta/stream info
    */
@@ -624,7 +632,12 @@ void _x_flush_events_queues (xine_stream_t *stream) {
     pthread_mutex_lock (&queue->lock);
     pthread_mutex_unlock (&stream->event_queues_lock);
 
-    if (queue->listener_thread != NULL) {
+    /* we might have been called from the very same function that
+     * processes events, therefore waiting here would cause deadlock.
+     * check only queues with listener threads which are not
+     * currently executing their callback functions.
+     */
+    if (queue->listener_thread != NULL && !queue->callback_running) {
       while (!xine_list_is_empty (queue->events)) {
         pthread_cond_wait (&queue->events_processed, &queue->lock);
       }
@@ -1329,7 +1342,7 @@ void xine_exit (xine_t *this) {
 #if defined(WIN32)
   WSACleanup();
 #endif
-  
+
   free (this);
 }
 
@@ -1340,7 +1353,7 @@ xine_t *xine_new (void) {
 #ifdef WIN32
     WSADATA Data;
     int i_err;
-#endif /*  WIN32 */
+#endif
 
   this = xine_xmalloc (sizeof (xine_t));
   if (!this)
