@@ -1,23 +1,23 @@
-/* 
- * Copyright (C) 2000-2002 the xine project
- * 
+/*
+ * Copyright (C) 2000-2005 the xine project
+ *
  * This file is part of xine, a free video player.
- * 
+ *
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * xine is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xineutils.h,v 1.20 2002/07/24 08:00:13 f1rmb Exp $
+ * $Id: xineutils.h,v 1.96 2004/12/12 13:51:30 valtri Exp $
  *
  */
 #ifndef XINEUTILS_H
@@ -27,14 +27,43 @@
 extern "C" {
 #endif
 
-#include <unistd.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
-#include <inttypes.h>
+#include <stdarg.h>
 #include <pthread.h>
-#include "attributes.h"
-#include "compat.h"
-#include "xmlparser.h"
+
+#ifdef XINE_COMPILE
+#  include <inttypes.h>
+#  include "attributes.h"
+#  include "compat.h"
+#  include "xmlparser.h"
+#  include "xine_buffer.h"
+#  include "configfile.h"
+#else
+#  ifdef WIN32
+#    include <winsock.h>
+#  else
+#    include <sys/time.h>
+#  endif
+#  include <xine/os_types.h>
+#  include <xine/attributes.h>
+#  include <xine/compat.h>
+#  include <xine/xmlparser.h>
+#  include <xine/xine_buffer.h>
+#  include <xine/configfile.h>
+#endif
+
+#include <stdio.h>
+#include <string.h>
+/* for alloca under MinGW */
+#ifdef HAVE_MALLOC_H
+#include <malloc.h>
+#endif
+
   /*
    * debugable mutexes
    */
@@ -47,7 +76,7 @@ extern "C" {
 
   int xine_mutex_init    (xine_mutex_t *mutex, const pthread_mutexattr_t *mutexattr,
 			  char *id);
-  
+
   int xine_mutex_lock    (xine_mutex_t *mutex, char *who);
   int xine_mutex_unlock  (xine_mutex_t *mutex, char *who);
   int xine_mutex_destroy (xine_mutex_t *mutex);
@@ -61,7 +90,7 @@ extern "C" {
  * long constant values MUST be suffixed by LL and unsigned long long
  * values by ULL, lest they be truncated by the compiler)
  */
-  
+
 /* generic accelerations */
 #define MM_ACCEL_MLIB           0x00000001
 
@@ -69,10 +98,18 @@ extern "C" {
 #define MM_ACCEL_X86_MMX        0x80000000
 #define MM_ACCEL_X86_3DNOW      0x40000000
 #define MM_ACCEL_X86_MMXEXT     0x20000000
-#define MM_ACCEL_X86_SSE	0x10000000
-#define MM_ACCEL_X86_SSE2	0x08000000
-/* powerpc accelerations */
+#define MM_ACCEL_X86_SSE        0x10000000
+#define MM_ACCEL_X86_SSE2       0x08000000
+
+/* powerpc accelerations and features */
 #define MM_ACCEL_PPC_ALTIVEC    0x04000000
+#define MM_ACCEL_PPC_CACHE32    0x02000000
+
+/* SPARC accelerations */
+
+#define MM_ACCEL_SPARC_VIS      0x01000000
+#define MM_ACCEL_SPARC_VIS2     0x00800000
+
 /* x86 compat defines */
 #define MM_MMX                  MM_ACCEL_X86_MMX
 #define MM_3DNOW                MM_ACCEL_X86_3DNOW
@@ -81,13 +118,12 @@ extern "C" {
 #define MM_SSE2                 MM_ACCEL_X86_SSE2
 
 uint32_t xine_mm_accel (void);
-/* uint32_t xine_mm_support (void) ; */
 
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
 
 typedef	union {
-	long long		q;	/* Quadword (64-bit) value */
-	unsigned long long	uq;	/* Unsigned Quadword */
+	int64_t			q;	/* Quadword (64-bit) value */
+	uint64_t		uq;	/* Unsigned Quadword */
 	int			d[2];	/* 2 Doubleword (32-bit) values */
 	unsigned int		ud[2];	/* 2 Unsigned Doubleword */
 	short			w[4];	/* 4 Word (16-bit) values */
@@ -102,16 +138,16 @@ typedef	union {
 #define	mmx_i2r(op,imm,reg) \
 	__asm__ __volatile__ (#op " %0, %%" #reg \
 			      : /* nothing */ \
-			      : "X" (imm) )
+			      : "i" (imm) )
 
 #define	mmx_m2r(op,mem,reg) \
 	__asm__ __volatile__ (#op " %0, %%" #reg \
 			      : /* nothing */ \
-			      : "X" (mem))
+			      : "m" (mem))
 
 #define	mmx_r2m(op,reg,mem) \
 	__asm__ __volatile__ (#op " %%" #reg ", %0" \
-			      : "=X" (mem) \
+			      : "=m" (mem) \
 			      : /* nothing */ )
 
 #define	mmx_r2r(op,regs,regd) \
@@ -551,32 +587,24 @@ typedef	union {
 #endif /*ARCH_X86 */
 
 
-
 		     /* Optimized/fast memcpy */
 
+/*
+   TODO : fix dll linkage problem for xine_fast_memcpy on win32
+
+   xine_fast_memcpy dll linkage is screwy here.
+   declaring as dllimport seems to fix the problem
+   but causes compiler warning with libxineutils
+*/
+#ifdef _MSC_VER
+__declspec( dllimport ) extern void *(* xine_fast_memcpy)(void *to, const void *from, size_t len);
+#else
 extern void *(* xine_fast_memcpy)(void *to, const void *from, size_t len);
+#endif
 
 #ifdef HAVE_XINE_INTERNAL_H
 /* Benchmark available memcpy methods */
-void xine_probe_fast_memcpy(config_values_t *config);
-#endif
-
-
-
-		      /* Debugging/Monitoring */
-
-#if (__GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 95) || !defined(__GNUC__)) && !defined(__cplusplus)
-#define xlerror(...) do {                                                        \
-        printf("XINE lib %s:%d:(%s) ", __FILE__, __LINE__, __XINE_FUNCTION__);   \
-        printf(__VA_ARGS__);                                                     \
-	printf("\n");                                                            \
-} while (0)
-#else
-#define xlerror(args...) do {                                                    \
-        printf("XINE lib %s:%d:(%s) ", __FILE__, __LINE__, __XINE_FUNCTION__);   \
-        printf(##args);                                                          \
-        printf("\n");                                                            \
-} while (0)
+void xine_probe_fast_memcpy(xine_t *xine);
 #endif
 
 
@@ -596,7 +624,11 @@ void xine_profiler_print_results (void);
  * Allocate and clean memory size_t 'size', then return the pointer
  * to the allocated memory.
  */
+#if !defined(__GNUC__) || __GNUC__ < 3
 void *xine_xmalloc(size_t size);
+#else
+void *xine_xmalloc(size_t size) __attribute__ ((__malloc__));
+#endif
 
 /*
  * Same as above, but memory is aligned to 'alignement'.
@@ -605,11 +637,20 @@ void *xine_xmalloc(size_t size);
  */
 void *xine_xmalloc_aligned(size_t alignment, size_t size, void **base);
 
-/* 
+/*
  * Get user home directory.
  */
 const char *xine_get_homedir(void);
 
+#if defined(WIN32) || defined(__CYGWIN__)
+/*
+ * Get other xine directories.
+ */
+const char *xine_get_plugindir(void);
+const char *xine_get_fontdir(void);
+const char *xine_get_localedir(void);
+#endif
+
 /*
  * Clean a string (remove spaces and '=' at the begin,
  * and '\n', '\r' and spaces at the end.
@@ -636,90 +677,17 @@ void xine_strdupa(char *dest, char *src);
                                 }                                           \
                               } while(0)
 
-/* Shamefully copied from glibc 2.2.3 */
-#ifdef HAVE_STRPBRK
-#define xine_strpbrk strpbrk
-#else
-static inline char *_x_strpbrk(const char *s, const char *accept) {
-
-  while(*s != '\0') {
-    const char *a = accept;
-    while(*a != '\0')
-      if(*a++ == *s)
-	return(char *) s;
-    ++s;
-  }
-
-  return NULL;
-}
-#define xine_strpbrk _x_strpbrk
-#endif
-
-#ifdef HAVE_STRSEP
-#define xine_strsep strsep
-#else
-static inline char *_x_strsep(char **stringp, const char *delim) {
-  char *begin, *end;
-  
-  begin = *stringp;
-  if(begin == NULL)
-    return NULL;
-  
-  if(delim[0] == '\0' || delim[1] == '\0') {
-    char ch = delim[0];
-    
-    if(ch == '\0')
-      end = NULL;
-    else {
-      if(*begin == ch)
-	end = begin;
-      else if(*begin == '\0')
-	end = NULL;
-      else
-	end = strchr(begin + 1, ch);
-    }
-  }
-  else
-    end = xine_strpbrk(begin, delim);
-  
-  if(end) {
-    *end++ = '\0';
-    *stringp = end;
-  }
-  else
-    *stringp = NULL;
-  
-  return begin;
-}
-#define xine_strsep _x_strsep
-#endif
-
-
-#ifdef	HAVE_SETENV
-#define	xine_setenv	setenv
-#else
-static inline void _x_setenv(const char *name, const char *val, int _xx)
-{
-  int len  = strlen(name) + strlen(val) + 2;
-  char *env;
-  
-  env = (char*)malloc(len);
-
-  if (env != NULL) {
-    strcpy(env, name);
-    strcat(env, "=");
-    strcat(env, val);
-    putenv(env);
-  }
-}
-#define	xine_setenv	_x_setenv
-#endif
+/* compatibility macros */
+#define xine_strpbrk(S, ACCEPT) strpbrk((S), (ACCEPT))
+#define xine_strsep(STRINGP, DELIM) strsep((STRINGP), (DELIM))
+#define xine_setenv(NAME, VAL, XX) setenv((NAME), (VAL), (XX))
 
 /*
  * Color Conversion Utility Functions
  * The following data structures and functions facilitate the conversion
- * of RGB images to packed YUV (YUY2) images. All of the meaty details
- * are written in color.c.
+ * of RGB images to packed YUV (YUY2) images. There are also functions to
+ * convert from YUV9 -> YV12. All of the meaty details are written in
+ * color.c.
  */
 
 typedef struct yuv_planes_s {
@@ -728,7 +696,6 @@ typedef struct yuv_planes_s {
   unsigned char *u;
   unsigned char *v;
   unsigned int row_width;    /* frame width */
-  unsigned int row_stride;   /* frame width + 2 */
   unsigned int row_count;    /* frame height */
 
 } yuv_planes_t;
@@ -739,6 +706,28 @@ void free_yuv_planes(yuv_planes_t *yuv_planes);
 
 extern void (*yuv444_to_yuy2)
   (yuv_planes_t *yuv_planes, unsigned char *yuy2_map, int pitch);
+extern void (*yuv9_to_yv12)
+  (unsigned char *y_src, int y_src_pitch, unsigned char *y_dest, int y_dest_pitch,
+   unsigned char *u_src, int u_src_pitch, unsigned char *u_dest, int u_dest_pitch,
+   unsigned char *v_src, int v_src_pitch, unsigned char *v_dest, int v_dest_pitch,
+   int width, int height);
+extern void (*yuv411_to_yv12)
+  (unsigned char *y_src, int y_src_pitch, unsigned char *y_dest, int y_dest_pitch,
+   unsigned char *u_src, int u_src_pitch, unsigned char *u_dest, int u_dest_pitch,
+   unsigned char *v_src, int v_src_pitch, unsigned char *v_dest, int v_dest_pitch,
+   int width, int height);
+extern void (*yv12_to_yuy2)
+  (unsigned char *y_src, int y_src_pitch,
+   unsigned char *u_src, int u_src_pitch,
+   unsigned char *v_src, int v_src_pitch,
+   unsigned char *yuy2_map, int yuy2_pitch,
+   int width, int height, int progressive);
+extern void (*yuy2_to_yv12)
+  (unsigned char *yuy2_map, int yuy2_pitch,
+   unsigned char *y_dst, int y_dst_pitch,
+   unsigned char *u_dst, int u_dst_pitch,
+   unsigned char *v_dst, int v_dst_pitch,
+   int width, int height);
 
 #define SCALEFACTOR 65536
 #define CENTERSAMPLE 128
@@ -753,17 +742,6 @@ extern void (*yuv444_to_yuy2)
   (unsigned char) \
   ((v_r_table[r] + v_g_table[g] + v_b_table[b]) / SCALEFACTOR + CENTERSAMPLE)
 
-#define FINISH_LINE(yuv_planes, row_ptr) \
-  yuv_planes.u[row_ptr + yuv_planes.row_width] = \
-    yuv_planes.u[row_ptr + yuv_planes.row_width - 1]; \
-  yuv_planes.u[row_ptr + yuv_planes.row_width + 1] = \
-    yuv_planes.u[row_ptr + yuv_planes.row_width - 2]; \
- \
-  yuv_planes.v[row_ptr + yuv_planes.row_width] = \
-    yuv_planes.v[row_ptr + yuv_planes.row_width - 1]; \
-  yuv_planes.v[row_ptr + yuv_planes.row_width + 1] = \
-    yuv_planes.v[row_ptr + yuv_planes.row_width - 2];
-
 #define UNPACK_BGR15(packed_pixel, r, g, b) \
   b = (packed_pixel & 0x7C00) >> 7; \
   g = (packed_pixel & 0x03E0) >> 2; \
@@ -796,6 +774,282 @@ extern int v_r_table[256];
 extern int v_g_table[256];
 extern int v_b_table[256];
 
+/* frame copying functions */
+extern void yv12_to_yv12
+  (unsigned char *y_src, int y_src_pitch, unsigned char *y_dst, int y_dst_pitch,
+   unsigned char *u_src, int u_src_pitch, unsigned char *u_dst, int u_dst_pitch,
+   unsigned char *v_src, int v_src_pitch, unsigned char *v_dst, int v_dst_pitch,
+   int width, int height);
+extern void yuy2_to_yuy2
+  (unsigned char *src, int src_pitch,
+   unsigned char *dst, int dst_pitch,
+   int width, int height);
+
+/* print a hexdump of the given data */
+void xine_hexdump (const char *buf, int length);
+
+/*
+ * Optimization macros for conditions
+ * Taken from the FIASCO L4 microkernel sources
+ */
+#if !defined(__GNUC__) || __GNUC__ < 3
+#  define EXPECT_TRUE(x)  (x)
+#  define EXPECT_FALSE(x) (x)
+#else
+#  define EXPECT_TRUE(x)  __builtin_expect((x),1)
+#  define EXPECT_FALSE(x) __builtin_expect((x),0)
+#endif
+
+#ifdef NDEBUG
+#define _x_assert(exp) \
+  do {                                                                \
+    if (!(exp))                                                       \
+      fprintf(stderr, "assert: %s:%d: %s: Assertion `%s' failed.\n",  \
+              __FILE__, __LINE__, __XINE_FUNCTION__, #exp);           \
+  } while(0)
+#else
+#define _x_assert(exp) \
+  do {                                                                \
+    if (!(exp)) {                                                     \
+      fprintf(stderr, "assert: %s:%d: %s: Assertion `%s' failed.\n",  \
+              __FILE__, __LINE__, __XINE_FUNCTION__, #exp);           \
+      abort();                                                        \
+    }                                                                 \
+  } while(0)
+#endif
+
+#define _x_abort()                                                    \
+  do {                                                                \
+    fprintf(stderr, "abort: %s:%d: %s: Aborting.\n",                  \
+            __FILE__, __LINE__, __XINE_FUNCTION__);                   \
+    abort();                                                          \
+  } while(0)
+
+
+/****** logging with xine **********************************/
+
+#ifndef LOG_MODULE
+  #define LOG_MODULE __FILE__
+#endif /* LOG_MODULE */
+
+#define LOG_MODULE_STRING printf("%s: ", LOG_MODULE );
+
+#ifdef LOG_VERBOSE
+  #define LONG_LOG_MODULE_STRING                                            \
+    printf("%s: (%s:%d) ", LOG_MODULE, __XINE_FUNCTION__, __LINE__ );
+#else
+  #define LONG_LOG_MODULE_STRING  LOG_MODULE_STRING
+#endif /* LOG_VERBOSE */
+
+#ifdef LOG
+  #ifdef __GNUC__
+    #define lprintf(fmt, args...)                                           \
+      do {                                                                  \
+        LONG_LOG_MODULE_STRING                                              \
+        printf(fmt, ##args);                                                \
+      } while(0)
+  #else /* __GNUC__ */
+    #ifdef _MSC_VER
+      #define lprintf(fmtargs)                                              \
+        do {                                                                \
+          LONG_LOG_MODULE_STRING                                            \
+          printf("%s", fmtargs);                                            \
+        } while(0)
+    #else /* _MSC_VER */
+      #define lprintf(fmt, ...)                                             \
+        do {                                                                \
+          LONG_LOG_MODULE_STRING                                            \
+          printf(__VA_ARGS__);                                              \
+        } while(0)
+    #endif  /* _MSC_VER */
+  #endif /* __GNUC__ */
+#else /* LOG */
+  #ifdef __GNUC__
+    #define lprintf(fmt, args...)     do {} while(0)
+  #else
+  #ifdef _MSC_VER
+void __inline lprintf(const char * fmt, ...) {};
+  #else
+    #define lprintf(...)              do {} while(0)
+  #endif /* _MSC_VER */
+  #endif /* __GNUC__ */
+#endif /* LOG */
+
+#ifdef __GNUC__
+  #define llprintf(cat, fmt, args...)                                       \
+    do{                                                                     \
+      if(cat){                                                              \
+        LONG_LOG_MODULE_STRING                                              \
+        printf( fmt, ##args );                                              \
+      }                                                                     \
+    }while(0)
+#else
+#ifdef _MSC_VER
+  #define llprintf(cat, fmtargs)                                            \
+    do{                                                                     \
+      if(cat){                                                              \
+        LONG_LOG_MODULE_STRING                                              \
+        printf( "%s", fmtargs );                                            \
+      }                                                                     \
+    }while(0)
+#else
+  #define llprintf(cat, ...)                                                \
+    do{                                                                     \
+      if(cat){                                                              \
+        LONG_LOG_MODULE_STRING                                              \
+        printf( __VA_ARGS__ );                                              \
+      }                                                                     \
+    }while(0)
+#endif /* _MSC_VER */
+#endif /* __GNUC__ */
+
+#ifdef  __GNUC__
+  #define xprintf(xine, verbose, fmt, args...)                              \
+    do {                                                                    \
+      if((xine) && (xine)->verbosity >= verbose){                           \
+        xine_log(xine, XINE_LOG_TRACE, fmt, ##args);                        \
+      }                                                                     \
+    } while(0)
+#else
+#ifdef _MSC_VER
+void xine_xprintf(xine_t *xine, int verbose, const char *fmt, ...);
+  #define xprintf xine_xprintf
+#else
+  #define xprintf(xine, verbose, ...)                                       \
+    do {                                                                    \
+      if((xine) && (xine)->verbosity >= verbose){                           \
+        xine_log(xine, XINE_LOG_TRACE, __VA_ARGS__);                        \
+      }                                                                     \
+    } while(0)
+#endif /* _MSC_VER */
+#endif /* __GNUC__ */
+
+/* time measuring macros for profiling tasks */
+
+#ifdef DEBUG
+#  define XINE_PROFILE(function)                                            \
+     do {                                                                   \
+       struct timeval current_time;                                         \
+       double dtime;                                                        \
+       gettimeofday(&current_time, NULL);                                   \
+       dtime = -(current_time.tv_sec + (current_time.tv_usec / 1000000.0)); \
+       function;                                                            \
+       gettimeofday(&current_time, NULL);                                   \
+       dtime += current_time.tv_sec + (current_time.tv_usec / 1000000.0);   \
+       printf("%s: (%s:%d) took %lf seconds\n",                             \
+              LOG_MODULE, __XINE_FUNCTION__, __LINE__, dtime);              \
+     } while(0)
+#  define XINE_PROFILE_ACCUMULATE(function)                                 \
+     do {                                                                   \
+       struct timeval current_time;                                         \
+       static double dtime = 0;                                             \
+       gettimeofday(&current_time, NULL);                                   \
+       dtime -= current_time.tv_sec + (current_time.tv_usec / 1000000.0);   \
+       function;                                                            \
+       gettimeofday(&current_time, NULL);                                   \
+       dtime += current_time.tv_sec + (current_time.tv_usec / 1000000.0);   \
+       printf("%s: (%s:%d) took %lf seconds\n",                             \
+              LOG_MODULE, __XINE_FUNCTION__, __LINE__, dtime);              \
+     } while(0)
+#else
+#  define XINE_PROFILE(function) function
+#  define XINE_PROFILE_ACCUMULATE(function) function
+#endif /* DEBUG */
+
+
+/******** double chained lists with builtin iterator *******/
+
+typedef struct xine_node_s {
+
+  struct xine_node_s    *next, *prev;
+
+  void                  *content;
+
+  int                    priority;
+
+} xine_node_t;
+
+
+typedef struct {
+
+  xine_node_t    *first, *last, *cur;
+
+} xine_list_t;
+
+
+
+xine_list_t *xine_list_new (void);
+
+
+/**
+ * dispose the whole list.
+ * note: disposes _only_ the list structure, content must be free()d elsewhere
+ */
+void xine_list_free(xine_list_t *l);
+
+
+/**
+ * returns: Boolean
+ */
+int xine_list_is_empty (xine_list_t *l);
+
+/**
+ * return content of first entry in list.
+ */
+void *xine_list_first_content (xine_list_t *l);
+
+/**
+ * return next content in list.
+ */
+void *xine_list_next_content (xine_list_t *l);
+
+/**
+ * Return last content of list.
+ */
+void *xine_list_last_content (xine_list_t *l);
+
+/**
+ * Return previous content of list.
+ */
+void *xine_list_prev_content (xine_list_t *l);
+
+/**
+ * Append content to list, sorted by decreasing priority.
+ */
+void xine_list_append_priority_content (xine_list_t *l, void *content, int priority);
+
+/**
+ * Append content to list.
+ */
+void xine_list_append_content (xine_list_t *l, void *content);
+
+/**
+ * Insert content in list.
+ */
+void xine_list_insert_content (xine_list_t *l, void *content);
+
+/**
+ * Remove current content in list.
+ * note: removes only the list entry; content must be free()d elsewhere.
+ */
+void xine_list_delete_current (xine_list_t *l);
+
+/**
+ * get encoding of current locale
+ */
+char *xine_get_system_encoding(void);
+
+/*
+ * guess default encoding for the subtitles
+ */
+const char *xine_guess_spu_encoding(void);
+
+/*
+ * use the best clock reference (API compatible with gettimeofday)
+ * note: it will be a monotonic clock, if available.
+ */
+int xine_monotonic_clock(struct timeval *tv, struct timezone *tz);      
+
 #ifdef __cplusplus
 }
 #endif
